package com.kym.service;

import com.kym.entity.SplitRecord;
import com.kym.entity.common.PageBean;
import com.kym.entity.queryParams.SplitRecordQueryParams;
import com.kym.entity.vo.SplitRecordVo;
import com.kym.service.mybatisplus.MyBaseService;

import java.time.LocalDate;
import java.util.Map;

/**
 * <p>
 * 平台分账记录表 服务类
 * </p>
 *
 * @author skyline
 * @since 2025-02-24
 */
public interface SplitRecordService extends MyBaseService<SplitRecord> {
    PageBean<SplitRecordVo> listSplitRecords(SplitRecordQueryParams params);

    Map<String, Integer> sumDailyIncome(LocalDate yesterday, Boolean... isCross);

    Map<String, Integer> sumMonthIncome(LocalDate statDay, Boolean... isCross);

    Map<String, Integer> sumDailyExpend(LocalDate statDay, Boolean... isCross);

    Map<String, Integer> sumMonthExpend(LocalDate statDay, Boolean... isCross);

    Map<String, Integer> sumDailyRefund(LocalDate statDay);

    Map<String, Integer> sumMonthRefund(LocalDate statDay);

    Map<String, Integer> countDailyRecharge(LocalDate statDay);

    Map<String, Integer> countMonthRecharge(LocalDate statDay);

    Map<String, Integer> countDailyRefund(LocalDate statDay);

    Map<String, Integer> countMonthRefund(LocalDate statDay);

    Map<String, Integer> sumDailyRechargeIncome(LocalDate statDay);

    Map<String, Integer> sumMonthRechargeIncome(LocalDate statDay);

    Map<String, Integer> sumDailyCrossIncome(LocalDate statDay);

    Map<String, Integer> sumMonthCrossIncome(LocalDate statDay);

    Map<String, Integer> sumDailyCrossExpend(LocalDate statDay);

    Map<String, Integer> sumMonthCrossExpend(LocalDate statDay);
}
